// --- [ debug.c ] ------------------------------------------------------------
//      30.11.09


#include <avr/io.h>
#include <inttypes.h>
#include <stdlib.h>
#include <string.h>
#include <util/delay.h>
#include <avr/eeprom.h>
#include <avr/interrupt.h>

#include "rs232.h"
#include "global.h"
#include "lcd.h"
#include "dcf_bits.h"
#include "dcf_77.h"

extern uint8_t error;


#ifdef LOG_RS232
// ----------------------------------------------------------------------------
// gibt die Zeit der aktuellen Minute aus
void print_datum(void)
{

/*
static uint8_t counter = 0;

put_c(13);

if (counter < 100) put_c('0');
if (counter <  10) put_c('0');
put_s(utoa(counter, msg,10));
put_c(' ');
counter++;
if (counter > 239) counter = 0;				// laufende Zeilennummer ausgeben
*/

put_c(' ');

if (time[CLK][STUNDE] < 10) put_c('0');	// Stunde und  Minuten
put_s(utoa(time[CLK][STUNDE], msg , 10));
put_c(':');
if (time[CLK][MINUTE] < 10) put_c('0');
put_s(utoa(time[CLK][MINUTE], msg, 10));

put_c('-');											// Sommer-/Winterzeit
if (is_summertime(&time[CLK][0])) put_c('s'); else put_c('w');
put_c('-');

if (time[CLK][TAG] < 10) put_c('0');		// Tag, Monat, Jahr
put_s(utoa(time[CLK][TAG],msg, 10 ));
put_c('.');
if (time[CLK][MONAT] < 10) put_c('0');
put_s(utoa(time[CLK][MONAT], msg, 10));
put_c('.');
if (time[CLK][JAHR] < 10) put_c('0');
put_s(utoa(time[CLK][JAHR], msg, 10));

put_c(' ');
}

// ----------------------------------------------------------------------------
// gibt die DCF-Bits ab Bit.15 der nchsten Minute aus
// als 0/1, die logischen Gruppen durch einen '.' getrennt
// positive Parittsprfung wird mit '!' dargestellt,
// Fehler in der Parittsprfung werden mit '?' markiert
void print_dcfbits(void)
{
uint8_t i, z;

// Ankndigungsbits -----------------------------------------------------------
for (i = 15; i < 21; i++)
{
	if (DCF_get_bit(i))
	{
		put_c('1');
		z++;
	}
	else put_c('0');
}
// Paritt

// Trenner
put_c('.');

// Minuten --------------------------------------------------------------------
z = 0;
for (i = 21; i < 28; i++)
{
	if (DCF_get_bit(i))
	{
		put_c('1');
		z++;
	}
	else put_c('0');
}
// Paritt
z += DCF_get_bit(28);
if (z & 1) put_c('?'); else put_c('!');	// Paritt muss immer gerade Zahl sein
// Trenner
put_c('.');

// Stunden --------------------------------------------------------------------
z = 0;
for (i = 29; i < 35; i++)
{
	if (DCF_get_bit(i))
	{
		put_c('1');
		z++;
	}
	else put_c('0');
}
// Paritt
z += DCF_get_bit(35);
if (z & 1) put_c('?'); else put_c('!');
// Trenner
put_c('.');

// der Rest --------------------------------------------------------------------
z = 0;
for (i = 36; i < 58; i++)
{
	if (i == 42) put_c('.');
	if (i == 45) put_c('.');
	if (i == 50) put_c('.');
	if (DCF_get_bit(i))
	{
		put_c('1');
		z++;
	}
	else put_c('0');
}
// Paritt
z += DCF_get_bit(58);
if (z & 1) put_c('?'); else put_c('!');

// Ankndigungsbits im Klartext -----------------------------------------------

if (time[DCF][ZBITS] & ~(0x03))				// wenn Ankndigungsbits im DCF-Signal gesendet wurden
														// die Bits fr Sommer-/Winterzeit ignorieren
	{
	if (!(error))									// nur Anzeigen, wenn das Datum fehlerfrei
		{
		if (time[DCF][ZBITS] & 0x10)	puts_p(PSTR(", A1"));
		if (time[DCF][ZBITS] & 0x08)	puts_p(PSTR(", A2"));
		if (time[DCF][ZBITS] & 0x04)	puts_p(PSTR(", R"));
		}
	}
}



#endif

// --- [ eof ] ----------------------------------------------------------------